@@ -1,11 +1,11 @@
 package Finance::Bank::ID::Base;
 
-our $DATE = '2015-04-28'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2015-04-29'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010;
 use Moo;
-use Log::Any;
+use Log::Any '$log';
 
 use Data::Dumper;
 use Data::Rmap qw(:all);
@@ -188,11 +188,10 @@ sub parse_statement {
                 }
             }
             if (abs($na-$nb) >= 0.01) {
-                $status = 400;
-                $error = "Check failed: total debit do not match ".
-                    "($na in summary line vs $nb when totalled from ".
-                        "$ntx transactions(s))";
-                last;
+                $log->warn(
+                    "Check failed: total debit do not match ".
+                        "($na in summary line vs $nb when totalled from ".
+                        "$ntx transactions(s))");
             }
         }
         if (defined($stmt->{_total_credit_in_stmt})) {
@@ -206,11 +205,10 @@ sub parse_statement {
                 }
             }
             if (abs($na-$nb) >= 0.01) {
-                $status = 400;
-                $error = "Check failed: total credit do not match ".
-                    "($na in summary line vs $nb when totalled from ".
-                        "$ntx transactions(s))";
-                last;
+                $log->warn(
+                    "Check failed: total credit do not match ".
+                        "($na in summary line vs $nb when totalled from ".
+                        "$ntx transactions(s))");
             }
         }
         if (defined($stmt->{_num_debit_tx_in_stmt})) {
@@ -279,7 +277,7 @@ Finance::Bank::ID::Base - Base class for Finance::Bank::ID::BCA etc
 
 =head1 VERSION
 
-This document describes version 0.35 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-04-28.
+This document describes version 0.36 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-04-29.
 
 =head1 SYNOPSIS
 
